On 06/08/2010 08:46 AM, Justin Clift wrote:
---
tools/virsh.c | 6 ++++--
1 files changed, 4 insertions(+), 2 deletions(-)
diff --git a/tools/virsh.c b/tools/virsh.c
index e444501..2e8cbec 100644
--- a/tools/virsh.c
+++ b/tools/virsh.c
@@ -9411,17 +9411,19 @@ vshCommandOptVolBy(vshControl *ctl, const vshCmd *cmd,
if (name)
*name = n;
/* try it by PATH */
if (pool && (flag & VSH_BYNAME)) {
- vshDebug(ctl, 5, "%s: <%s> trying as vol UUID\n",
+ vshDebug(ctl, 5, "%s: <%s> trying as vol name\n",
ACK; pushed.
@@ -9411,17 +9411,19 @@ vshCommandOptVolBy(vshControl *ctl, const vshCmd *cmd,
if (name)
*name = n;
- /* try it by PATH */
+ /* try it by name */
if (pool && (flag & VSH_BYNAME)) {
--
Eric Blake eblake(a)redhat.com +1-801-349-2682
Libvirt virtualization library
http://libvirt.org